@@ -10,6 +10,7 @@
 #undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
 #undef HAVE_PROGRAM_INVOCATION_NAME
 #undef HAVE_SYS_ERRLIST
+#undef HAVE_LIBUTIL
 #undef HAVE_LIBJPEG
 #undef HAVE_LIBGIF
 #undef HAVE_LIBTIFF
@@ -30,10 +31,23 @@
 #undef HAVE_LIBAUDIOFILE
 #undef umode_t
 #undef HAVE_OPENPTY
-#undef HAVE_PTY_H
-#undef HAVE_UTIL_H
+#undef HAVE_LOGIN_TTY
 #undef HAVE_SENDMSG
 #undef NEED_DECLARATION_SCANDIR
 #undef HAVE_IMLIB_1_9
 
+/* We define macro, which expands to utmpx or utmp when available */
+#undef UTMP
+
+#undef HAVE_UT_UT_PID
+#undef HAVE_UT_UT_ID
+#undef HAVE_UT_UT_USER
+#undef HAVE_UT_UT_NAME
+#undef HAVE_UT_UT_TYPE
+#undef HAVE_UT_UT_HOST
+#undef HAVE_UT_UT_TV
+#undef HAVE_UT_UT_TIME
+#undef HAVE_UT_UT_SYSLEN
+#undef HAVE_UT_UT_EXIT_E_TERMINATION
+
 #undef WITH_SYMBOL_UNDERSCORE
