@@ -60,7 +60,7 @@ static gint dentry_edit_signals[LAST_SIGNAL] = { 0 };
 static GtkObjectClass *parent_class;
 
 guint
-gnome_dentry_edit_get_type ()
+gnome_dentry_edit_get_type (void)
 {
   static guint dee_type = 0;
 
@@ -121,7 +121,6 @@ gnome_dentry_edit_class_init (GnomeDEntryEditClass *klass)
 		    gtk_signal_default_marshaller,
 		    GTK_TYPE_NONE, 0);
 
-
   gtk_object_class_add_signals (object_class, dentry_edit_signals, 
 				LAST_SIGNAL);
 
@@ -129,36 +128,46 @@ gnome_dentry_edit_class_init (GnomeDEntryEditClass *klass)
   dentry_edit_class->changed = NULL;
 }
 
-#define TABLE_ENTRY_OPTIONS (GTK_EXPAND | GTK_FILL)
-#define TABLE_LABEL_OPTIONS 0
-
 static void 
 table_attach_entry(GtkTable * table, GtkWidget * w,
 		   gint l, gint r, gint t, gint b)
 {
-  gtk_table_attach(table,w, l, r, t, b, 
-		   TABLE_ENTRY_OPTIONS, TABLE_ENTRY_OPTIONS, 
-		   GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+  gtk_table_attach(table, w, l, r, t, b,
+		   GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+		   GTK_FILL,
+		   0, 0);
 }
 
 static void
 table_attach_label(GtkTable * table, GtkWidget * w,
 		   gint l, gint r, gint t, gint b)
 {
-  gtk_table_attach(table,w, l, r, t, b, 
-		   TABLE_LABEL_OPTIONS, TABLE_LABEL_OPTIONS, 
-		   GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+  gtk_table_attach(table, w, l, r, t, b,
+		   GTK_FILL,
+		   GTK_FILL,
+		   0, 0);
 }
 
+static GtkWidget *
+label_new (char *text)
+{
+  GtkWidget *label;
+
+  label = gtk_label_new (text);
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  return label;
+}
 
 static void
 fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
 {
-  GtkWidget * label;
-  GList * types = NULL;
+  GtkWidget *label;
+  GList *types = NULL;
   GtkWidget *e;
+  GtkWidget *hbox;
+  GtkWidget *align;
 
-  label = gtk_label_new(_("Name:"));
+  label = label_new(_("Name:"));
   table_attach_label(GTK_TABLE(table), label, 0, 1, 0, 1);
 
   dee->name_entry = gtk_entry_new();
@@ -171,7 +180,7 @@ fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
 					GTK_OBJECT(dee));
 
 
-  label = gtk_label_new(_("Comment:"));
+  label = label_new(_("Comment:"));
   table_attach_label(GTK_TABLE(table),label, 0, 1, 1, 2);
 
   dee->comment_entry = gtk_entry_new();
@@ -181,7 +190,7 @@ fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
 					GTK_OBJECT(dee));
 
 
-  label = gtk_label_new(_("Command:"));
+  label = label_new(_("Command:"));
   table_attach_label(GTK_TABLE(table),label, 0, 1, 2, 3);
 
   dee->exec_entry = gtk_entry_new();
@@ -191,8 +200,8 @@ fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
 					GTK_OBJECT(dee));
 
 
-  label = gtk_label_new(_("Type:"));
-  table_attach_label(GTK_TABLE(table),label, 0, 1, 3, 4);
+  label = label_new(_("Type:"));
+  table_attach_label(GTK_TABLE(table), label, 0, 1, 3, 4);
 
   types = g_list_prepend(types, "Application");
   types = g_list_prepend(types, "Directory");
@@ -207,6 +216,16 @@ fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
 					GTK_SIGNAL_FUNC(gnome_dentry_edit_changed),
 					GTK_OBJECT(dee));
 
+  label = label_new(_("Icon:"));
+  table_attach_label(GTK_TABLE(table), label, 0, 1, 4, 5);
+
+  hbox = gtk_hbox_new(FALSE, GNOME_PAD_BIG);
+  gtk_table_attach(GTK_TABLE(table), hbox,
+		   1, 2, 4, 5,
+		   GTK_EXPAND | GTK_FILL,
+		   0,
+		   0, 0);
+
   dee->icon_entry = gnome_icon_entry_new("icon",_("Choose an icon"));
   e = gnome_icon_entry_gtk_entry(GNOME_ICON_ENTRY(dee->icon_entry));
   gtk_signal_connect_object_while_alive(GTK_OBJECT(e),"changed",
@@ -215,19 +234,17 @@ fill_easy_page(GnomeDEntryEdit * dee, GtkWidget * table)
   gtk_signal_connect_object_while_alive(GTK_OBJECT(e),"changed",
 					GTK_SIGNAL_FUNC(gnome_dentry_edit_icon_changed),
 					GTK_OBJECT(dee));
+  gtk_box_pack_start(GTK_BOX(hbox), dee->icon_entry, FALSE, FALSE, 0);
 
-  gtk_table_attach(GTK_TABLE(table),dee->icon_entry, 
-		   0, 2, 5, 6, 0, 0, GNOME_PAD_SMALL, 
-		   GNOME_PAD_SMALL);
+  align = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+  gtk_box_pack_start(GTK_BOX(hbox), align, FALSE, FALSE, 0);
 
-  dee->terminal_button = 
-    gtk_check_button_new_with_label (_("Run in Terminal"));
+  dee->terminal_button = gtk_check_button_new_with_label (_("Run in Terminal"));
   gtk_signal_connect_object(GTK_OBJECT(dee->terminal_button), 
 			    "clicked",
 			    GTK_SIGNAL_FUNC(gnome_dentry_edit_changed),
 			    GTK_OBJECT(dee));
-  gtk_table_attach(GTK_TABLE(table),dee->terminal_button, 1, 2, 6, 7,
-		   0, 0, GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+  gtk_container_add(GTK_CONTAINER(align), dee->terminal_button);
 }
 
 static void
@@ -235,19 +252,19 @@ fill_advanced_page(GnomeDEntryEdit * dee, GtkWidget * page)
 {
   GtkWidget * label;
 
-  label = gtk_label_new(_("Try this before using:"));
+  label = label_new(_("Try this before using:"));
   table_attach_label(GTK_TABLE(page),label, 0, 1, 0, 1);
-  
+
   dee->tryexec_entry = gtk_entry_new();
   table_attach_entry(GTK_TABLE(page),dee->tryexec_entry, 1, 2, 0, 1);
   gtk_signal_connect_object(GTK_OBJECT(dee->tryexec_entry), 
 			    "changed",
 			    GTK_SIGNAL_FUNC(gnome_dentry_edit_changed),
 			    GTK_OBJECT(dee));
-  
-  label = gtk_label_new(_("Documentation:"));
+
+  label = label_new(_("Documentation:"));
   table_attach_label(GTK_TABLE(page),label, 0, 1, 1, 2);
-  
+
   dee->doc_entry = gtk_entry_new_with_max_length(255);
   table_attach_entry(GTK_TABLE(page),dee->doc_entry, 1, 2, 1, 2);
   gtk_signal_connect_object(GTK_OBJECT(dee->doc_entry), 
@@ -261,13 +278,15 @@ make_page(void)
 {
   GtkWidget * frame, * page;
 
-  frame = gtk_frame_new(NULL);
-  gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
-  
-  page = gtk_table_new(7, 2, FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (page), GNOME_PAD_SMALL);
+  frame = gtk_frame_new (NULL);
+  gtk_container_set_border_width (GTK_CONTAINER(frame), GNOME_PAD_SMALL);
 
-  gtk_container_add (GTK_CONTAINER(frame), page);
+  page = gtk_table_new (5, 2, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (page), GNOME_PAD_SMALL);
+  gtk_table_set_row_spacings (GTK_TABLE (page), GNOME_PAD_SMALL);
+  gtk_table_set_col_spacings (GTK_TABLE (page), GNOME_PAD_SMALL);
+
+  gtk_container_add (GTK_CONTAINER (frame), page);
 
   return frame;
 } 
@@ -279,7 +298,8 @@ gnome_dentry_edit_init (GnomeDEntryEdit *dee)
   dee->child2       = NULL;
 }
 
-GtkObject * gnome_dentry_edit_new (void)
+GtkObject *
+gnome_dentry_edit_new (void)
 {
   GnomeDEntryEdit * dee;
 
@@ -297,7 +317,8 @@ GtkObject * gnome_dentry_edit_new (void)
 }
 
 
-GtkObject * gnome_dentry_edit_new_notebook (GtkNotebook * notebook)
+GtkObject *
+gnome_dentry_edit_new_notebook (GtkNotebook *notebook)
 {
   GnomeDEntryEdit * dee;
 
@@ -305,23 +326,24 @@ GtkObject * gnome_dentry_edit_new_notebook (GtkNotebook * notebook)
   
   dee = GNOME_DENTRY_EDIT(gnome_dentry_edit_new());
 
-  gtk_notebook_append_page ( GTK_NOTEBOOK(notebook), 
-			     dee->child1, 
-			     gtk_label_new(_("Basic")) );
+  gtk_notebook_append_page (GTK_NOTEBOOK(notebook), 
+			    dee->child1, 
+			    gtk_label_new(_("Basic")));
 
-  gtk_notebook_append_page ( GTK_NOTEBOOK(notebook), 
-			     dee->child2, 
-			     gtk_label_new(_("Advanced")) );
+  gtk_notebook_append_page (GTK_NOTEBOOK(notebook), 
+			    dee->child2, 
+			    gtk_label_new(_("Advanced")));
 
   /* Destroy self with the notebook. */
   gtk_signal_connect_object(GTK_OBJECT(notebook), "destroy",
-					GTK_SIGNAL_FUNC(gtk_object_destroy),
-					GTK_OBJECT(dee));
+			    GTK_SIGNAL_FUNC(gtk_object_destroy),
+			    GTK_OBJECT(dee));
 
   return GTK_OBJECT (dee);
 }
 
-static void gnome_dentry_edit_destroy (GtkObject *dee)
+static void
+gnome_dentry_edit_destroy (GtkObject *dee)
 {
   g_return_if_fail(dee != NULL);
   g_return_if_fail(GNOME_IS_DENTRY_EDIT(dee));
@@ -331,8 +353,9 @@ static void gnome_dentry_edit_destroy (GtkObject *dee)
 }
 
 /* Conform display to dentry */
-static void gnome_dentry_edit_sync_display(GnomeDEntryEdit * dee,
-					   GnomeDesktopEntry * dentry)
+static void
+gnome_dentry_edit_sync_display(GnomeDEntryEdit *dee,
+			       GnomeDesktopEntry *dentry)
 {
   gchar * s = NULL;
   g_return_if_fail(dee != NULL);
@@ -343,7 +366,8 @@ static void gnome_dentry_edit_sync_display(GnomeDEntryEdit * dee,
   gtk_entry_set_text(GTK_ENTRY(dee->comment_entry),
 		     dentry->comment ? dentry->comment : "");
   
-  if (dentry->exec) s = g_flatten_vector(" ", dentry->exec);
+  if (dentry->exec)
+    s = g_flatten_vector(" ", dentry->exec);
   gtk_entry_set_text(GTK_ENTRY(dee->exec_entry), s ? s : "");
   g_free(s);
 
@@ -357,15 +381,16 @@ static void gnome_dentry_edit_sync_display(GnomeDEntryEdit * dee,
 		     dentry->docpath ? dentry->docpath : "");
 
   gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dee->type_combo)->entry),
-			       dentry->type ? dentry->type : "");
+		     dentry->type ? dentry->type : "");
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dee->terminal_button),
-			      dentry->terminal);
+			       dentry->terminal);
 }
 
 /* Conform dentry to display */
-static void gnome_dentry_edit_sync_dentry(GnomeDEntryEdit * dee,
-					  GnomeDesktopEntry * dentry)
+static void
+gnome_dentry_edit_sync_dentry(GnomeDEntryEdit *dee,
+			      GnomeDesktopEntry *dentry)
 {
   gchar * text;
 
@@ -375,39 +400,40 @@ static void gnome_dentry_edit_sync_dentry(GnomeDEntryEdit * dee,
 
   text = gtk_entry_get_text(GTK_ENTRY(dee->name_entry));
   g_free(dentry->name);
-  if (text[0] != '\0') dentry->name = g_strdup(text);
+  if (text[0] != '\0')
+    dentry->name = g_strdup(text);
 
   text = gtk_entry_get_text(GTK_ENTRY(dee->comment_entry));
   g_free(dentry->comment);
-  if (text[0] != '\0') dentry->comment = g_strdup(text);
+  if (text[0] != '\0')
+    dentry->comment = g_strdup(text);
 
   text = gtk_entry_get_text(GTK_ENTRY(dee->exec_entry));
   g_strfreev(dentry->exec);
-  if (text[0] != '\0') {
-    gnome_config_make_vector(text,
-			     &dentry->exec_length,
-			     &dentry->exec);
-  } else {
+  if (text[0] != '\0')
+    gnome_config_make_vector(text, &dentry->exec_length, &dentry->exec);
+  else
     dentry->exec_length = 0;
-  }
 
   text = gtk_entry_get_text(GTK_ENTRY(dee->tryexec_entry));
   g_free(dentry->tryexec);
-  if (text[0] != '\0') dentry->tryexec = g_strdup(text);
+  if (text[0] != '\0')
+    dentry->tryexec = g_strdup(text);
   
   text = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(dee->type_combo)->entry));
   g_free(dentry->type);
-  if (text[0] != '\0') dentry->type = g_strdup(text);
+  if (text[0] != '\0')
+    dentry->type = g_strdup(text);
   
   g_free(dentry->icon);
   dentry->icon = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(dee->icon_entry));
 
   text = gtk_entry_get_text(GTK_ENTRY(dee->doc_entry));
   g_free(dentry->docpath);
-  if (text[0] != '\0') dentry->docpath = g_strdup(text);
+  if (text[0] != '\0')
+    dentry->docpath = g_strdup(text);
 
-  dentry->terminal = 
-    GTK_TOGGLE_BUTTON(dee->terminal_button)->active;
+  dentry->terminal = GTK_TOGGLE_BUTTON(dee->terminal_button)->active;
 
   g_free(dentry->location);
   dentry->location = NULL;
@@ -415,8 +441,9 @@ static void gnome_dentry_edit_sync_dentry(GnomeDEntryEdit * dee,
   dentry->geometry = NULL;
 }
 
-void        gnome_dentry_edit_load_file  (GnomeDEntryEdit * dee,
-					  const gchar * path)
+void
+gnome_dentry_edit_load_file(GnomeDEntryEdit *dee,
+			    const gchar *path)
 {
   GnomeDesktopEntry * newentry;
 
@@ -426,11 +453,10 @@ void        gnome_dentry_edit_load_file  (GnomeDEntryEdit * dee,
 
   newentry = gnome_desktop_entry_load_unconditional(path);
 
-  if ( newentry ) {
+  if (newentry) {
     gnome_dentry_edit_sync_display(dee, newentry);
     gnome_desktop_entry_destroy(newentry);
-  }
-  else {
+  } else {
     g_warning("Failed to load file into GnomeDEntryEdit");
     return;
   }
@@ -438,8 +464,9 @@ void        gnome_dentry_edit_load_file  (GnomeDEntryEdit * dee,
 
 /* Destroy existing dentry and replace it with this one,
    updating the DEntryEdit to reflect it. */
-void        gnome_dentry_edit_set_dentry(GnomeDEntryEdit * dee,
-					 GnomeDesktopEntry * dentry)
+void
+gnome_dentry_edit_set_dentry(GnomeDEntryEdit *dee,
+			     GnomeDesktopEntry *dentry)
 {
   g_return_if_fail(dee != NULL);
   g_return_if_fail(GNOME_IS_DENTRY_EDIT(dee));
@@ -448,7 +475,8 @@ void        gnome_dentry_edit_set_dentry(GnomeDEntryEdit * dee,
   gnome_dentry_edit_sync_display(dee, dentry);
 }
 
-GnomeDesktopEntry * gnome_dentry_get_dentry(GnomeDEntryEdit * dee)
+GnomeDesktopEntry *
+gnome_dentry_get_dentry(GnomeDEntryEdit *dee)
 {
   GnomeDesktopEntry * newentry;
 
@@ -456,13 +484,12 @@ GnomeDesktopEntry * gnome_dentry_get_dentry(GnomeDEntryEdit * dee)
   g_return_val_if_fail(GNOME_IS_DENTRY_EDIT(dee), NULL);
 
   newentry = g_new0(GnomeDesktopEntry, 1);
-
   gnome_dentry_edit_sync_dentry(dee, newentry);
-  
   return newentry;
 }
 
-void        gnome_dentry_edit_clear     (GnomeDEntryEdit * dee)
+void
+gnome_dentry_edit_clear(GnomeDEntryEdit *dee)
 {
   g_return_if_fail(dee != NULL);
   g_return_if_fail(GNOME_IS_DENTRY_EDIT(dee));
@@ -475,73 +502,73 @@ void        gnome_dentry_edit_clear     (GnomeDEntryEdit * dee)
   gnome_icon_entry_set_icon(GNOME_ICON_ENTRY(dee->icon_entry),"");
 }
 
-static void gnome_dentry_edit_changed(GnomeDEntryEdit * dee)
+static void
+gnome_dentry_edit_changed(GnomeDEntryEdit *dee)
 {
-  gtk_signal_emit(GTK_OBJECT(dee), 
-		  dentry_edit_signals[CHANGED],
-		  NULL);
+  gtk_signal_emit(GTK_OBJECT(dee), dentry_edit_signals[CHANGED], NULL);
 }
 
-static void gnome_dentry_edit_icon_changed(GnomeDEntryEdit * dee)
+static void
+gnome_dentry_edit_icon_changed(GnomeDEntryEdit *dee)
 {
-  gtk_signal_emit(GTK_OBJECT(dee), 
-		  dentry_edit_signals[ICON_CHANGED],
-		  NULL);
+  gtk_signal_emit(GTK_OBJECT(dee), dentry_edit_signals[ICON_CHANGED], NULL);
 }
 
-static void gnome_dentry_edit_name_changed(GnomeDEntryEdit * dee)
+static void
+gnome_dentry_edit_name_changed(GnomeDEntryEdit *dee)
 {
-  gtk_signal_emit(GTK_OBJECT(dee), 
-		  dentry_edit_signals[NAME_CHANGED],
-		  NULL);
+  gtk_signal_emit(GTK_OBJECT(dee), dentry_edit_signals[NAME_CHANGED], NULL);
 }
 
-gchar *     gnome_dentry_edit_get_icon   (GnomeDEntryEdit * dee)
+gchar *
+gnome_dentry_edit_get_icon(GnomeDEntryEdit *dee)
 {
   g_return_val_if_fail(dee != NULL, NULL);
  
   return gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(dee->icon_entry));
 }
 
-gchar *     gnome_dentry_edit_get_name   (GnomeDEntryEdit * dee)
+gchar *
+gnome_dentry_edit_get_name (GnomeDEntryEdit *dee)
 {
   gchar * name;
+
   name = gtk_entry_get_text(GTK_ENTRY(dee->name_entry));
   return g_strdup(name);
 }
 
 GtkWidget *
-gnome_dentry_get_name_entry      (GnomeDEntryEdit * dee)
+gnome_dentry_get_name_entry (GnomeDEntryEdit *dee)
 {
   return dee->name_entry;
 }
 
 GtkWidget *
-gnome_dentry_get_comment_entry   (GnomeDEntryEdit * dee)
+gnome_dentry_get_comment_entry (GnomeDEntryEdit *dee)
 {
   return dee->comment_entry;
 }
 
 GtkWidget *
-gnome_dentry_get_exec_entry      (GnomeDEntryEdit * dee)
+gnome_dentry_get_exec_entry (GnomeDEntryEdit *dee)
 {
   return dee->exec_entry;
 }
 
 GtkWidget *
-gnome_dentry_get_tryexec_entry   (GnomeDEntryEdit * dee)
+gnome_dentry_get_tryexec_entry (GnomeDEntryEdit *dee)
 {
   return dee->tryexec_entry;
 }
 
 GtkWidget *
-gnome_dentry_get_doc_entry       (GnomeDEntryEdit * dee)
+gnome_dentry_get_doc_entry (GnomeDEntryEdit *dee)
 {
   return dee->doc_entry;
 }
 
 GtkWidget *
-gnome_dentry_get_icon_entry      (GnomeDEntryEdit * dee)
+gnome_dentry_get_icon_entry (GnomeDEntryEdit *dee)
 {
   return dee->icon_entry;
 }
@@ -550,27 +577,29 @@ gnome_dentry_get_icon_entry      (GnomeDEntryEdit * dee)
 
 #include "libgnomeui.h"
 
-static void changed_callback(GnomeDEntryEdit * dee, gpointer data)
+static void
+changed_callback(GnomeDEntryEdit *dee, gpointer data)
 {
   g_print("Changed!\n");
   fflush(stdout);
 }
 
-static void icon_changed_callback(GnomeDEntryEdit * dee, 
-				  gpointer data)
+static void
+icon_changed_callback(GnomeDEntryEdit *dee, gpointer data)
 {
   g_print("Icon changed!\n");
   fflush(stdout);
 }
 
-static void name_changed_callback(GnomeDEntryEdit * dee, 
-				  gpointer data)
+static void
+name_changed_callback(GnomeDEntryEdit *dee, gpointer data)
 {
   g_print("Name changed!\n");
   fflush(stdout);
 }
 
-int main (int argc, char * argv[])
+int
+main(int argc, char * argv[])
 {
   GtkWidget * app;
   GtkWidget * notebook;
