@@ -415,7 +415,10 @@ gnome_init_with_popt_table(const char *app_id,
 	gnomelib_init (app_id, app_version);
 	
 	gnome_register_options();
-	
+
+	if (getenv ("GTK_DEBUG_OBJECTS"))
+		gtk_debug_flags |= GTK_DEBUG_OBJECTS;
+		
 	gnome_client_init();
 	
 	if(options) {
@@ -623,7 +626,25 @@ relay_gtk_signal(GtkObject *object,
 {
 #ifdef HAVE_ESD
   char *pieces[3] = {"gtk-events", NULL, NULL};
+  static GQuark disable_sound_quark = 0;
+
   pieces[1] = signame;
+
+  if(!disable_sound_quark)
+    disable_sound_quark = g_quark_from_static_string("gnome_disable_sound_events");
+
+  if(gtk_object_get_data_by_id(object, disable_sound_quark))
+    return TRUE;
+
+  if(GTK_IS_WIDGET(object)) {
+    if(!GTK_WIDGET_DRAWABLE(object))
+      return TRUE;
+
+    if(GTK_IS_MENU_ITEM(object) && GTK_MENU_ITEM(object)->submenu)
+      return TRUE;
+  }
+
+
   gnome_triggers_vdo("", NULL, (const char **)pieces);
 
   return TRUE;
