@@ -757,9 +757,9 @@ normal_loading:
 
   g_return_val_if_fail(gmod, CORBA_OBJECT_NIL);
   g_module_make_resident(gmod);
-  g_return_val_if_fail(g_module_symbol(gmod, "GNOME_Plugin_info",
-				       (gpointer *)&plugin),
-		       CORBA_OBJECT_NIL);
+  i = g_module_symbol(gmod, "GNOME_Plugin_info",
+		      (gpointer *)&plugin);
+  g_return_val_if_fail(i, CORBA_OBJECT_NIL);
 
   for(i = 0; plugin->plugin_object_list[i].repo_id; i++) {
     if(!strcmp(sinfo->server_id, plugin->plugin_object_list[i].server_id))
@@ -859,6 +859,7 @@ get_cmd(gchar* line)
   gchar* ptr;
   gint   argc = 1;
   gchar* tok;
+  gchar* tokp;
   
   retval.argv = (gchar**)malloc(sizeof(char*) * 2);
   retval.argv[1] = 0;
@@ -871,11 +872,11 @@ get_cmd(gchar* line)
   if (!*ptr)
     return &retval;
 
-  retval.cmd = strtok(ptr, " \t");
+  retval.cmd = strtok_r(ptr, " \t", &tokp);
   retval.argv[0] = retval.cmd;
   while (1)
     {
-      tok = strtok(0, " \t");
+      tok = strtok_r(0, " \t", &tokp);
       if (!tok)
 	return &retval;
       argc++;
@@ -1051,9 +1052,9 @@ out:
 /**
  * goad_server_register:
  * @name_server: points to a running name_server
- * @server: the server we wnat to register.
- * @name:
- * @kind:
+ * @server: the server object we want to register.
+ * @name: The GOAD id of the server that is being registered
+ * @kind: "server" for now.
  * @ev: CORBA_Environment to return errors
  *
  * Registers @server in the @name_server with @name.
@@ -1115,13 +1116,11 @@ goad_server_register(CORBA_Object name_server,
 
   old_server = CosNaming_NamingContext_resolve(name_server, &nom, ev);
 
-  if(ev->_major == CORBA_NO_EXCEPTION) {
+  if(ev->_major == CORBA_NO_EXCEPTION
+     || (ev->_major == CORBA_USER_EXCEPTION
+	 && strcmp(CORBA_exception_id(ev),
+		   ex_CosNaming_NamingContext_NotFound))) {
     CORBA_Object_release(old_server, ev);
-    CosNaming_NamingContext_unbind(name_server, &nom, ev);
-    g_return_val_if_fail(ev->_major == CORBA_NO_EXCEPTION, -3);
-  } else if (ev->_major != CORBA_USER_EXCEPTION 
-	     || strcmp(CORBA_exception_id(ev),
-		       ex_CosNaming_NamingContext_NotFound)) {
 
     if(orig_ns == CORBA_OBJECT_NIL)
       CORBA_Object_release(name_server, ev);
