@@ -205,7 +205,7 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
 	((c & (VTATTR_MASK^VTATTR_FORECOLOURM)) != 
 	 (l->data[i] & (VTATTR_MASK^VTATTR_FORECOLOURM)))) {
 
-#if 0
+#if 1
       d(printf("bl->data[i] = %08x != %08x, c=%d (back now=%d not %d)\n", 
 	       bl->data[i], l->data[i], c, 
 	       (l->data[i]&VTATTR_BACKCOLOURM)>>VTATTR_BACKCOLOURB, 
@@ -214,10 +214,10 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
       vx->back_match = 0;
       break;
     } else {
-#if 0
+#if 1
       d(printf("bl->data[i] == %08x == %08x, c=%08x back=%d\n",
 	       bl->data[i], l->data[i], c,
-	       (l->data[i]&VTATTR_BACKCOLOURM)>>VTATTR_BACKCOLOURB);
+	       (l->data[i]&VTATTR_BACKCOLOURM)>>VTATTR_BACKCOLOURB));
 #endif
     }
   }
@@ -1080,7 +1080,7 @@ void vt_draw_cursor(struct _vtx *vx, int state)
   unsigned char c;
   uint32 attr;
 
-  if (vx->vt.scrollbackold == 0) {
+  if (vx->vt.scrollbackold == 0 && vx->vt.cursorx<vx->vt.width) {
     attr = vx->vt.this_line->data[vx->vt.cursorx];
     c = attr & 0xff;
     if (c==9 || c==0)			/* remap tab */
